@@ -9,11 +9,9 @@ OC.L10N.register(
     "Copy to full name" : "フルネームをコピー",
     "Omit year" : "年を省略する",
     "Allow updating avatars from social media" : "ソーシャルメディアからのアバターの更新を許可する",
+    "There was an error fetching the member list" : "メンバーリストの取得中にエラーが発生しました",
     "Please select a team" : "チームを選択してください",
     "Loading team…" : "チームを読み込み中...",
-    "Your request to join this team is pending approval" : "このチームへの参加リクエストは承認待ちです",
-    "You are not a member of {circle}" : "あなたはサークル{circle}のメンバーではありません",
-    "There was an error fetching the member list" : "メンバーリストの取得中にエラーが発生しました",
     "Loading contacts …" : "連絡先を読み込み中...",
     "There are no contacts yet" : "連絡先はまだありません",
     "Create contact" : "連絡先を作成",
@@ -34,24 +32,22 @@ OC.L10N.register(
     "Send email" : "メールを送信",
     "Send email as BCC" : "BCCでメール送信",
     "Delete" : "削除",
+    "Show all groups" : "すべてのグループを表示",
+    "Collapse groups" : "グループを折りたたむ",
+    "Show all teams" : "すべてのチームを表示",
+    "Collapse teams" : "チームを折りたたむ",
+    "Group name cannot be empty" : "グループ名を空にすることはできません",
+    "This group already exists" : "このグループはすでに存在しています",
+    "An error occurred while creating the group" : "グループ作成中にエラーが発生しました",
+    "This team already exists" : "このチームはすでに存在しています",
+    "An error happened during the creation of the team" : "チームの作成中にエラーが発生しました",
     "Contact groups" : "連絡先グループ",
     "Create a new contact group" : "新規連絡先グループを作成",
     "Contact group name" : "連絡先グループ名",
     "Teams" : "チーム",
     "Create a new team" : "新しいチームを作成する",
     "Open the contacts app settings" : "連絡先アプリの設定を開く",
-    "Show all groups" : "すべてのグループを表示",
-    "Collapse groups" : "グループを折りたたむ",
-    "Show all teams" : "すべてのチームを表示",
-    "Collapse teams" : "チームを折りたたむ",
-    "This group already exists" : "このグループはすでに存在しています",
-    "An error occurred while creating the group" : "グループ作成中にエラーが発生しました",
-    "This team already exists" : "このチームはすでに存在しています",
-    "An error happened during the creation of the team" : "チームの作成中にエラーが発生しました",
-    "{addressbookname} (Disabled)" : "{addressbookname} (無効)",
-    "Download" : "ダウンロード",
-    "Show" : "表示",
-    "Unshare from me" : "共有を自分から解除",
+    "_Shared with {num} entity_::_Shared with {num} entities_" : ["{num} 個のエンティティと共有"],
     "Copied" : "コピーしました",
     "Cannot copy" : "コピーできません",
     "Copy link" : "リンクをコピー",
@@ -62,23 +58,27 @@ OC.L10N.register(
     "Unshare {addressbook}?" : "{addressbook}の共有を解除しますか?",
     "Deletion of address book was not successful." : "アドレス帳の削除に失敗しました。",
     "Renaming of address book was not successful." : "アドレス帳の名前変更に失敗しました。",
+    "{addressbookname} (Disabled)" : "{addressbookname} (無効)",
+    "Download" : "ダウンロード",
+    "Show" : "表示",
+    "Unshare from me" : "共有を自分から解除",
     "_%n contact_::_%n contacts_" : ["%n 連絡先"],
     "_%n group_::_%n groups_" : ["%n グループ"],
     "Share with users or groups" : "ユーザーまたはグループと共有する",
     "Share with users" : "ユーザーに共有",
     "No users or groups" : "ユーザーまたはグループはありません",
-    "can edit" : "編集を許可",
     "Unable to delete the share" : "共有を削除できません",
     "Unable to change permissions" : "権限を変更できません。",
+    "can edit" : "編集を許可",
+    "Choose a vCard file to import" : "インポートするvCardファイルを選択",
     "Import contacts" : "連絡先のインポート",
     "Import into the {addressbookName} address book" : "アドレス帳 {addressbookName} にインポートします",
     "Select local file" : "ローカルファイルの選択",
     "Import from files" : "ファイルからインポート ",
     "Importing is disabled because there are no address books available" : "使用可能なアドレス帳がないため、インポートは無効です",
-    "Choose a vCard file to import" : "インポートするvCardファイルを選択",
+    "An error occurred, unable to create the address book" : "エラーが発生し、アドレス帳を作成できませんでした。",
     "Add new address book" : "新しいアドレス帳を追加する",
     "Add" : "Add",
-    "An error occurred, unable to create the address book" : "エラーが発生し、アドレス帳を作成できませんでした。",
     "First name" : "名",
     "Last name" : "姓",
     "Phonetic first name" : "めい",
@@ -96,31 +96,25 @@ OC.L10N.register(
     "Save" : "保存",
     "Change unique password" : "固有パスワードを変更",
     "Failed to save password. Please try again later." : "パスワードを保存できませんでした。後でもう一度やり直してください",
+    "There is no description for this team" : "このチームの説明はありません",
+    "Enter a description for the team" : "チームの説明を入力します",
+    "An error happened during description sync" : "説明の同期中にエラーが発生しました",
+    "An error happened during name sync" : "名前の同期中にエラーが発生しました",
     "Team owned by {owner}" : "{owner}が所有するチーム",
     "Team settings" : "チーム設定",
     "Request to join" : "参加リクエスト",
     "Description" : "詳細",
-    "Members" : "メンバー",
-    "Manage members" : "メンバーの管理",
-    "Team members" : "チームのメンバー",
+    "Your request to join this team is pending approval" : "このチームへの参加リクエストは承認待ちです",
+    "You are not a member of {circle}" : "あなたはサークル{circle}のメンバーではありません",
     "Team resources" : "チームのリソース",
     "Anything shared with this team will show up here" : "このチームと共有されているものはすべてここに表示されます",
     "Team name" : "チーム名",
     "Settings" : "Settings",
     "Actions" : "アクション",
-    "There is no description for this team" : "このチームの説明はありません",
-    "Enter a description for the team" : "チームの説明を入力します",
-    "An error happened during description sync" : "説明の同期中にエラーが発生しました",
-    "An error happened during name sync" : "名前の同期中にエラーが発生しました",
-    "Cancel" : "キャンセル",
     "Confirm" : "承認",
+    "Cancel" : "キャンセル",
     "Add more info" : "さらに情報を追加",
     "More fields" : "その他のフィールド",
-    "Crop contact photo" : "写真を切り抜き",
-    "Upload a new picture" : "新しい写真をアップロードする",
-    "Choose from Files" : "ファイルから選択",
-    "Download picture" : "画像をダウンロード",
-    "Delete picture" : "画像を削除",
     "Please select a valid format" : "有効なフォーマットを選択してください。",
     "Invalid image" : "無効な画像",
     "Error cropping picture" : "画像のトリミング中にエラーが発生しました",
@@ -130,9 +124,26 @@ OC.L10N.register(
     "Avatar downloaded from social network" : "SNSでダウンロード済みのアバター",
     "Avatar already up to date" : "アバターはすでに最新です",
     "Avatar download failed" : "アバターのダウンロードに失敗しました",
+    "Crop contact photo" : "写真を切り抜き",
+    "Upload a new picture" : "新しい写真をアップロードする",
+    "Choose from Files" : "ファイルから選択",
+    "Download picture" : "画像をダウンロード",
+    "Delete picture" : "画像を削除",
+    "This contact is in read-only mode. You do not have permission to edit this contact." : "この連絡先は読み取り専用モードです。 この連絡先を編集する権限がありません。",
+    "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "編集しようとした連絡先が変更されました。 連絡先を手動で更新してください。 それ以上の編集は破棄されます。",
+    "Address book" : "アドレス帳",
+    "Add contact to Birthday Calendar" : "誕生日カレンダーに連絡先を追加する",
+    "Exclude contact from Birthday Calendar" : "誕生日カレンダーから連絡先を除外する",
+    "{title} at {organization}" : "{organization}の{title}",
+    "Name" : "名前",
+    "Syntax error. Cannot open the contact." : "構文エラー。 連絡先を開けません",
+    "The contact does not exist on the server anymore." : "連絡先はサーバー上に存在しません。",
+    "Unable to retrieve the contact from the server, please check your network connection." : "サーバーから連絡先を取得できないので、ネットワークの接続をご確認ください。",
+    "An error occurred while trying to move the contact" : "連絡先の移動中にエラーが発生しました",
+    "An error occurred while trying to copy the contact" : "連絡先のコピー中にエラーが発生しました",
+    "Unable to update contact" : "連絡先を更新できません",
     "No contact selected" : "連絡先が選択されていません",
     "Select a contact on the list to begin" : "開始するには、リストの連絡先を選択してください",
-    "Name" : "名前",
     "Title" : "タイトル",
     "Company" : "会社",
     "Go to talk conversation" : "Talkのチャットへ移動",
@@ -149,25 +160,13 @@ OC.L10N.register(
     "Calendar events with you" : "カレンダーイベント",
     "Deck cards with you" : "デッキカード",
     "No shared items with this contact" : "この連絡先との共有アイテムはありません",
-    "This contact is in read-only mode. You do not have permission to edit this contact." : "この連絡先は読み取り専用モードです。 この連絡先を編集する権限がありません。",
-    "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "編集しようとした連絡先が変更されました。 連絡先を手動で更新してください。 それ以上の編集は破棄されます。",
-    "Address book" : "アドレス帳",
-    "Add contact to Birthday Calendar" : "誕生日カレンダーに連絡先を追加する",
-    "Exclude contact from Birthday Calendar" : "誕生日カレンダーから連絡先を除外する",
-    "{title} at {organization}" : "{organization}の{title}",
-    "Syntax error. Cannot open the contact." : "構文エラー。 連絡先を開けません",
-    "The contact does not exist on the server anymore." : "連絡先はサーバー上に存在しません。",
-    "Unable to retrieve the contact from the server, please check your network connection." : "サーバーから連絡先を取得できないので、ネットワークの接続をご確認ください。",
-    "An error occurred while trying to move the contact" : "連絡先の移動中にエラーが発生しました",
-    "An error occurred while trying to copy the contact" : "連絡先のコピー中にエラーが発生しました",
-    "Unable to update contact" : "連絡先を更新できません",
     "Search contacts …" : "連絡先を検索...",
     "Add to {group}" : "{group}に追加",
     "Remove {type}" : "{type} を削除",
+    "Add to group" : "グループに追加",
     "Search {types}" : "{types} を検索",
     "Search for people to add" : "追加するメンバーを検索",
     "No results" : "該当なし",
-    "Add to group" : "グループに追加",
     "Add {type}" : "{type}を追加",
     "New team name" : "新しいチーム名",
     "Personal team" : "パーソナルチーム",
@@ -175,20 +174,15 @@ OC.L10N.register(
     "Local team" : "ローカルチーム",
     "This team will not be shared with the other instances of the global scale" : "このチームはグローバルスケールの他のインスタンスと共有されません",
     "Create team" : "チームを作成する",
+    "Unable to get the results" : "結果を取得できません",
+    "Some members could not be added" : "一部のメンバーを追加できませんでした",
+    "There was an issue adding members to the team" : "チームへのメンバーの追加で問題が発生しました",
+    "Team members" : "チームのメンバー",
     "Loading members list …" : "メンバーリストを読み込んでいます…",
     "The list of members is only visible to members of this team" : "メンバーのリストは、このチームのメンバーにのみ表示されます",
     "You currently have no access to the member list" : "メンバーリストへのアクセス権がありません",
     "Add members" : "メンバーの追加",
-    "Show team details" : "チームの詳細を表示",
     "Add to {circle}" : "{circle} に追加",
-    "Unable to get the recommendations list" : "おすすめリストを取得できません",
-    "Unable to get the results" : "結果を取得できません",
-    "Some members could not be added" : "一部のメンバーを追加できませんでした",
-    "There was an issue adding members to the team" : "チームへのメンバーの追加で問題が発生しました",
-    "Accept membership request" : "メンバーシップリクエストを受け入れる",
-    "Reject membership request" : "メンバーシップリクエストを拒否",
-    "Manage level" : "レベルを管理",
-    "Remove member" : "メンバーを削除",
     "Pending" : "保留中",
     "Promote as sole owner" : "唯一の所有者に昇格",
     "Promote to {level}" : "{level}に昇格",
@@ -196,19 +190,28 @@ OC.L10N.register(
     "Could not delete the member {displayName}" : "メンバー{displayName}を削除できませんでした",
     "Could not change the member level to {level}" : "メンバーレベルを{level}に変更できませんでした",
     "Could not accept membership request" : "メンバーシップリクエストを承諾できませんでした",
-    "Chart" : "チャート",
+    "Accept membership request" : "メンバーシップリクエストを受け入れる",
+    "Reject membership request" : "メンバーシップリクエストを拒否",
+    "Manage level" : "レベルを管理",
+    "Remove member" : "メンバーを削除",
     "Select chart …" : "組織図を選択...",
-    "Select type" : "タイプを選択",
+    "Chart" : "チャート",
     "Select Date" : "日付を選択",
+    "Select type" : "タイプを選択",
     "Add contact in group" : "グループに連絡先を追加",
     "None" : "なし",
     "Select option" : "オプションを選択",
     "Add property of this type" : "このタイプのプロパティーを追加",
-    "New contact" : "新しい連絡先",
     "Unable to create the contact." : "連絡先を追加できません。",
     "Contact not found" : "連絡先がありません",
     "Group {group} not found" : "グループ {group} が見つかりません",
+    "New contact" : "新しい連絡先",
+    "_{success} contact added to {name}_::_{success} contacts added to {name}_" : ["{success} 件の連絡先を {name} に追加しました"],
+    "_Adding {success} contact to {name}_::_Adding {success} contacts to {name}_" : ["{success} 件の連絡先を {name} に追加中"],
+    "_{count} error_::_{count} errors_" : ["{count} つのエラー"],
     "Close" : "閉じる",
+    "_Importing %n contact into {addressbook}_::_Importing %n contacts into {addressbook}_" : ["{アドレス帳}に %n の連絡先をインポートしています。"],
+    "_Done importing %n contact into {addressbook}_::_Done importing %n contacts into {addressbook}_" : ["{アドレス帳}に %n 連絡先のインポートが完了しました"],
     "No data for this contact" : "この連絡先のデータはありません",
     "No data for this contact on their profile" : "プロフィールにこの連絡先のデータがありません",
     "Import" : "インポート",
@@ -247,9 +250,13 @@ OC.L10N.register(
     "Team membership" : "チームのメンバー",
     "Prevent teams from being a member of another team" : "チームが別のチームのメンバーになることを禁止する",
     "users" : "ユーザー",
+    "Users" : "ユーザー",
     "groups" : "グループ",
+    "Groups" : "グループ",
     "teams" : "チーム",
     "email addresses" : "メールアドレス",
+    "Email addresses" : "メールアドレス",
+    "contacts" : "連絡先",
     "Detailed name" : "詳細名",
     "Additional names" : "ミドルネーム",
     "Prefix" : "プレフィックス",
@@ -316,6 +323,9 @@ OC.L10N.register(
     "Unable to delete team {circleId}" : "チーム {circleId} を削除できません",
     "Unable to delete contact" : "連絡先を削除できません。",
     "Memberships must be confirmed/accepted by a Moderator (requires Open)" : "メンバーシップは、モデレーターにより確認/承認が必要です（開く要求）",
-    "Manager" : "マネージャー"
+    "Manager" : "マネージャー",
+    "Members" : "メンバー",
+    "Manage members" : "メンバーの管理",
+    "Show team details" : "チームの詳細を表示"
 },
 "nplurals=1; plural=0;");
