@@ -9,11 +9,9 @@ OC.L10N.register(
     "Copy to full name" : "複製到全名",
     "Omit year" : "省略年份",
     "Allow updating avatars from social media" : "允許從社群媒體更新大頭照",
+    "There was an error fetching the member list" : "擷取成員清單時發生錯誤",
     "Please select a team" : "請選取團隊",
     "Loading team…" : "正在載入團隊……",
-    "Your request to join this team is pending approval" : "您加入此團隊的請求正在等待批准",
-    "You are not a member of {circle}" : "您不是 {circle} 的成員",
-    "There was an error fetching the member list" : "擷取成員清單時發生錯誤",
     "Loading contacts …" : "正在載入聯絡人……",
     "There are no contacts yet" : "目前沒有連絡人",
     "Create contact" : "建立聯絡人",
@@ -34,24 +32,22 @@ OC.L10N.register(
     "Send email" : "傳送電子郵件",
     "Send email as BCC" : "以密件副本傳送電子郵件",
     "Delete" : "刪除",
+    "Show all groups" : "顯示所有群組",
+    "Collapse groups" : "折疊群組",
+    "Show all teams" : "顯示所有團隊",
+    "Collapse teams" : "折疊團隊",
+    "Group name cannot be empty" : "群組名稱不能為空",
+    "This group already exists" : "該群組已存在",
+    "An error occurred while creating the group" : "建立群組時發生錯誤",
+    "This team already exists" : "此團隊已存在",
+    "An error happened during the creation of the team" : "建立團隊時發生錯誤",
     "Contact groups" : "聯絡人群組",
     "Create a new contact group" : "建立新聯絡人群組",
     "Contact group name" : "聯絡人群組名稱",
     "Teams" : "團隊",
     "Create a new team" : "建立新團隊",
     "Open the contacts app settings" : "開啟通訊錄應用程式設定",
-    "Show all groups" : "顯示所有群組",
-    "Collapse groups" : "折疊群組",
-    "Show all teams" : "顯示所有團隊",
-    "Collapse teams" : "折疊團隊",
-    "This group already exists" : "該群組已存在",
-    "An error occurred while creating the group" : "建立群組時發生錯誤",
-    "This team already exists" : "此團隊已存在",
-    "An error happened during the creation of the team" : "建立團隊時發生錯誤",
-    "{addressbookname} (Disabled)" : "{addressbookname}（已停用）",
-    "Download" : "下載",
-    "Show" : "顯示",
-    "Unshare from me" : "取消與我分享",
+    "_Shared with {num} entity_::_Shared with {num} entities_" : ["與 {num} 個實體分享"],
     "Copied" : "已複製",
     "Cannot copy" : "無法複製",
     "Copy link" : "複製連結",
@@ -62,23 +58,27 @@ OC.L10N.register(
     "Unshare {addressbook}?" : "取消分享 {addressbook}？",
     "Deletion of address book was not successful." : "刪除通訊錄失敗。",
     "Renaming of address book was not successful." : "重新命名通訊錄失敗。",
+    "{addressbookname} (Disabled)" : "{addressbookname}（已停用）",
+    "Download" : "下載",
+    "Show" : "顯示",
+    "Unshare from me" : "取消與我分享",
     "_%n contact_::_%n contacts_" : ["%n 位聯絡人"],
     "_%n group_::_%n groups_" : ["%n 個群組"],
     "Share with users or groups" : "與使用者或群組分享",
     "Share with users" : "與使用者分享",
     "No users or groups" : "沒有使用者或群組",
-    "can edit" : "允許編輯",
     "Unable to delete the share" : "無法刪除這個分享",
     "Unable to change permissions" : "無法變更權限",
+    "can edit" : "允許編輯",
+    "Choose a vCard file to import" : "選取要匯入的 vCard 檔案",
     "Import contacts" : "匯入連絡人",
     "Import into the {addressbookName} address book" : "匯入至 {addressbookName} 通訊錄",
     "Select local file" : "選取本機檔案",
     "Import from files" : "從檔案匯入",
     "Importing is disabled because there are no address books available" : "已停用匯入，因為沒有可用的通訊錄",
-    "Choose a vCard file to import" : "選取要匯入的 vCard 檔案",
+    "An error occurred, unable to create the address book" : "發生錯誤，無法建立通訊錄",
     "Add new address book" : "加入新的通訊錄",
     "Add" : "Add",
-    "An error occurred, unable to create the address book" : "發生錯誤，無法建立通訊錄",
     "First name" : "名",
     "Last name" : "姓",
     "Phonetic first name" : "語音名",
@@ -96,31 +96,25 @@ OC.L10N.register(
     "Save" : "儲存",
     "Change unique password" : "變更獨一無二的密碼",
     "Failed to save password. Please try again later." : "儲存密碼失敗。請稍後再試。",
+    "There is no description for this team" : "此團隊沒有描述",
+    "Enter a description for the team" : "輸入團隊的描述",
+    "An error happened during description sync" : "描述同步時發生錯誤",
+    "An error happened during name sync" : "名稱同步時發生錯誤",
     "Team owned by {owner}" : "{owner} 擁有的團隊",
     "Team settings" : "團隊設定",
     "Request to join" : "要求加入",
     "Description" : "描述",
-    "Members" : "成員",
-    "Manage members" : "管理成員",
-    "Team members" : "團隊成員",
+    "Your request to join this team is pending approval" : "您加入此團隊的請求正在等待批准",
+    "You are not a member of {circle}" : "您不是 {circle} 的成員",
     "Team resources" : "團隊資源",
     "Anything shared with this team will show up here" : "與此團隊分享的任何東西都會顯示在此處",
     "Team name" : "團隊名稱",
     "Settings" : "Settings",
     "Actions" : "動作",
-    "There is no description for this team" : "此團隊沒有描述",
-    "Enter a description for the team" : "輸入團隊的描述",
-    "An error happened during description sync" : "描述同步時發生錯誤",
-    "An error happened during name sync" : "名稱同步時發生錯誤",
-    "Cancel" : "取消",
     "Confirm" : "確認",
+    "Cancel" : "取消",
     "Add more info" : "新增更多資訊",
     "More fields" : "更多欄位",
-    "Crop contact photo" : "裁剪聯絡人照片",
-    "Upload a new picture" : "上傳一張新的圖片",
-    "Choose from Files" : "從檔案選取",
-    "Download picture" : "下載圖片",
-    "Delete picture" : "刪除圖片",
     "Please select a valid format" : "請選取有效格式",
     "Invalid image" : "圖片無效",
     "Error cropping picture" : "裁剪照片時發生錯誤",
@@ -130,9 +124,26 @@ OC.L10N.register(
     "Avatar downloaded from social network" : "從社群網路下載大頭照",
     "Avatar already up to date" : "大頭照已是最新",
     "Avatar download failed" : "大頭照下載失敗",
+    "Crop contact photo" : "裁剪聯絡人照片",
+    "Upload a new picture" : "上傳一張新的圖片",
+    "Choose from Files" : "從檔案選取",
+    "Download picture" : "下載圖片",
+    "Delete picture" : "刪除圖片",
+    "This contact is in read-only mode. You do not have permission to edit this contact." : "此聯絡人處於唯讀模式。您無權編輯此聯絡人。",
+    "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "您嘗試編輯的聯絡人已變更。請手動重新整理聯絡人。任何進一步的編輯都會被丟棄。",
+    "Address book" : "通訊錄",
+    "Add contact to Birthday Calendar" : "將聯絡人新增至生日行事曆",
+    "Exclude contact from Birthday Calendar" : "從生日行事曆排除聯絡人",
+    "{title} at {organization}" : "{organization} 的 {title}",
+    "Name" : "名稱",
+    "Syntax error. Cannot open the contact." : "語法錯誤。無法開啟聯絡人。",
+    "The contact does not exist on the server anymore." : "伺服器上不再存在該聯絡人。",
+    "Unable to retrieve the contact from the server, please check your network connection." : "無法從伺服器擷取聯絡人，請檢查您的網路連線。",
+    "An error occurred while trying to move the contact" : "嘗試移動聯絡人時發生錯誤",
+    "An error occurred while trying to copy the contact" : "嘗試複製聯絡人時發生錯誤",
+    "Unable to update contact" : "無法更新聯絡人",
     "No contact selected" : "未選擇聯絡人",
     "Select a contact on the list to begin" : "在列表中選擇一個聯絡人以開始",
-    "Name" : "名稱",
     "Title" : "標題",
     "Company" : "公司",
     "Go to talk conversation" : "前往對話",
@@ -149,25 +160,13 @@ OC.L10N.register(
     "Calendar events with you" : "有您的日曆事件",
     "Deck cards with you" : "有您的 Deck 卡片",
     "No shared items with this contact" : "沒有與該聯絡人分享的項目",
-    "This contact is in read-only mode. You do not have permission to edit this contact." : "此聯絡人處於唯讀模式。您無權編輯此聯絡人。",
-    "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "您嘗試編輯的聯絡人已變更。請手動重新整理聯絡人。任何進一步的編輯都會被丟棄。",
-    "Address book" : "通訊錄",
-    "Add contact to Birthday Calendar" : "將聯絡人新增至生日行事曆",
-    "Exclude contact from Birthday Calendar" : "從生日行事曆排除聯絡人",
-    "{title} at {organization}" : "{organization} 的 {title}",
-    "Syntax error. Cannot open the contact." : "語法錯誤。無法開啟聯絡人。",
-    "The contact does not exist on the server anymore." : "伺服器上不再存在該聯絡人。",
-    "Unable to retrieve the contact from the server, please check your network connection." : "無法從伺服器擷取聯絡人，請檢查您的網路連線。",
-    "An error occurred while trying to move the contact" : "嘗試移動聯絡人時發生錯誤",
-    "An error occurred while trying to copy the contact" : "嘗試複製聯絡人時發生錯誤",
-    "Unable to update contact" : "無法更新聯絡人",
     "Search contacts …" : "搜尋聯絡人……",
     "Add to {group}" : "新增至 {group}",
     "Remove {type}" : "移除 {type}",
+    "Add to group" : "新增至群組",
     "Search {types}" : "搜尋 {types}",
     "Search for people to add" : "搜尋要新增的人",
     "No results" : "沒有結果",
-    "Add to group" : "新增至群組",
     "Add {type}" : "新增 {type}",
     "New team name" : "新團隊名稱",
     "Personal team" : "個人團隊",
@@ -175,20 +174,15 @@ OC.L10N.register(
     "Local team" : "本地團隊",
     "This team will not be shared with the other instances of the global scale" : "這個團隊不會與全球的其他站台共享",
     "Create team" : "建立團隊",
+    "Unable to get the results" : "無法取得結果",
+    "Some members could not be added" : "無法新增部份成員",
+    "There was an issue adding members to the team" : "將成員新增至團隊時發生錯誤",
+    "Team members" : "團隊成員",
     "Loading members list …" : "正在載入成員清單……",
     "The list of members is only visible to members of this team" : "成員清單僅有此團隊的成員可見",
     "You currently have no access to the member list" : "您目前無權存取成員清單",
     "Add members" : "新增成員",
-    "Show team details" : "顯示團隊詳細資訊",
     "Add to {circle}" : "新增至 {circle}",
-    "Unable to get the recommendations list" : "無法取得建議清單",
-    "Unable to get the results" : "無法取得結果",
-    "Some members could not be added" : "無法新增部份成員",
-    "There was an issue adding members to the team" : "將成員新增至團隊時發生錯誤",
-    "Accept membership request" : "接受成員資格請求",
-    "Reject membership request" : "拒絕成員資格請求",
-    "Manage level" : "管理等級",
-    "Remove member" : "移除成員",
     "Pending" : "擱置中",
     "Promote as sole owner" : "將其權限升級為唯一擁有者",
     "Promote to {level}" : "將其權限升級為 {level}",
@@ -196,19 +190,29 @@ OC.L10N.register(
     "Could not delete the member {displayName}" : "無法刪除成員 {displayName}",
     "Could not change the member level to {level}" : "無法變更成員等級至 {level}",
     "Could not accept membership request" : "無法接受成員請求",
-    "Chart" : "圖表",
+    "Accept membership request" : "接受成員資格請求",
+    "Reject membership request" : "拒絕成員資格請求",
+    "Manage level" : "管理等級",
+    "Remove member" : "移除成員",
     "Select chart …" : "選取圖表……",
-    "Select type" : "選取類型",
+    "Chart" : "圖表",
     "Select Date" : "選取日期",
+    "Select type" : "選取類型",
     "Add contact in group" : "新增聯絡人到群組",
     "None" : "無",
     "Select option" : "選取選項",
+    "Personal dates" : "個人日期",
     "Add property of this type" : "新增此類型的屬性",
-    "New contact" : "新聯絡人",
     "Unable to create the contact." : "無法建立聯絡人",
     "Contact not found" : "找不到聯絡人",
     "Group {group} not found" : "找不到群組 {group}",
+    "New contact" : "新聯絡人",
+    "_{success} contact added to {name}_::_{success} contacts added to {name}_" : ["{success} 個聯絡人已新增至 {name}"],
+    "_Adding {success} contact to {name}_::_Adding {success} contacts to {name}_" : ["已新增 {success} 個聯絡人至 {name}"],
+    "_{count} error_::_{count} errors_" : ["{count} 個錯誤"],
     "Close" : "關閉",
+    "_Importing %n contact into {addressbook}_::_Importing %n contacts into {addressbook}_" : ["正在匯入 %n 個聯絡人至 {addressbook}"],
+    "_Done importing %n contact into {addressbook}_::_Done importing %n contacts into {addressbook}_" : ["完成匯入 %n 個聯絡人至 {addressbook}"],
     "No data for this contact" : "此聯絡人無資料",
     "No data for this contact on their profile" : "此聯絡人的個人檔案中沒有資料",
     "Import" : "匯入",
@@ -247,9 +251,13 @@ OC.L10N.register(
     "Team membership" : "團隊成員資格",
     "Prevent teams from being a member of another team" : "避免團隊成為其他團隊的成員",
     "users" : "使用者",
+    "Users" : "使用者",
     "groups" : "群組",
+    "Groups" : "群組",
     "teams" : "團隊",
     "email addresses" : "電子郵件地址",
+    "Email addresses" : "電子郵件地址",
+    "contacts" : "聯絡人",
     "Detailed name" : "詳細名稱",
     "Additional names" : "別名/中間名",
     "Prefix" : "前綴",
@@ -316,6 +324,9 @@ OC.L10N.register(
     "Unable to delete team {circleId}" : "無法刪除團隊 {circleId}",
     "Unable to delete contact" : "無法刪除聯絡人",
     "Memberships must be confirmed/accepted by a Moderator (requires Open)" : "成員資格必須由主持人（必須為開放小圈圈）確認／接受",
-    "Manager" : "經理"
+    "Manager" : "經理",
+    "Members" : "成員",
+    "Manage members" : "管理成員",
+    "Show team details" : "顯示團隊詳細資訊"
 },
 "nplurals=1; plural=0;");
